@@ -17,7 +17,7 @@ from .utils import backoff_retry
 
 
 class Badminton():
-    """珠海校区羽毛球场预定脚本
+    """珠海校区羽毛球场预订脚本
     """
 
     def __init__(self, configpath, begin_time='00:01', max_times=10, token=''):
@@ -55,7 +55,7 @@ class Badminton():
             else:
                 self.stock_date = datetime.strptime(
                     conf['stock_date'], "%Y-%m-%d").date()
-            # 预定日期前一天 00:00 可以预定，当天 22:00 后无法预定
+            # 预订日期前一天 00:00 可以预订，当天 22:00 后无法预订
             self.begin_time = datetime.strptime(begin_time, "%H:%M").time()
             self.begin_datetime = datetime.combine(self.stock_date,
                                                    self.begin_time) - timedelta(days=1)
@@ -64,13 +64,13 @@ class Badminton():
             print('检查配置文件填写是否正确')
             sys.exit()
 
-        print(f'预定日期: {self.stock_date}')
-        print(f"预定场次: {conf['stock_name']}\n预定时间: {conf['stock_time']}")
-        print(f'每个时间段最大预定场地数: {self.stock_number}')
+        print(f'预订日期: {self.stock_date}')
+        print(f"预订场次: {conf['stock_name']}\n预订时间: {conf['stock_time']}")
+        print(f'每个时间段最大预订场地数: {self.stock_number}')
 
 
     def get_stocks(self):
-        """获取指定日期可预定的场次列表
+        """获取指定日期可预订的场次列表
         """
         gym_url = 'https://gym.sysu.edu.cn/product/findOkArea.html'
         try_times = 0
@@ -141,24 +141,23 @@ class Badminton():
 
 
     def _recognize(self):
-        """调用 http://fast.95man.com 在线识别验证码
+        """调用 cascaptcha 在线识别验证码
         """
         headers = {'Connection': 'Keep-Alive',
-                   'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)'}
+                'Authorization': self.token,
+                'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)'}
         files = {'imgfile': ('captcha.jpg', self.imbyte)}
         recg_times = 0
         try:
             while recg_times < self.max_times:
-                r = requests.post(f'http://api.95man.com:8888/api/Http/Recog?Taken={self.token}&imgtype=1&len=4',
-                                files=files, headers=headers)
-                arrstr = r.text.split('|')
-                # 返回格式: 识别ID|识别结果|用户余额
-                if int(arrstr[0]) > 0:
-                    print(f'验证码识别成功: {arrstr[1]}')
-                    self.capt = arrstr[1]
+                r = requests.post('https://cascaptcha.vercel.app/api', files=files, headers=headers)
+                arrstr = json.loads(r.text)
+                if arrstr["success"]:
+                    print(f'验证码识别成功: {arrstr["captcha"]}')
+                    self.capt = arrstr["captcha"]
                     return True
                 recg_times += 1
-                print(f'识别失败: {arrstr[1]}，第 {recg_times} 次重试')
+                print(f'识别失败，第 {recg_times} 次重试')
                 sleep(1)
             raise Exception('识别失败，重试次数达到上限')
 
@@ -229,12 +228,12 @@ class Badminton():
                 print(f'当前时间 {datetime.now()}，开始预订')
                 return
             self.begin_datetime += timedelta(days=1)
-            print('预订系统关闭，等到明天开始预定')
+            print('预订系统关闭，等到明天开始预订')
 
-        print(f'未到可预订时间，等到 {self.begin_datetime} 开始预定')
+        print(f'未到可预订时间，等到 {self.begin_datetime} 开始预订')
         if (self.begin_datetime - datetime.now()).days > 0:
             print('!!!警告!!!')
-            print('等待时间超过一天，建议等到明天再来预定!!!')
+            print('等待时间超过一天，建议等到明天再来预订!!!')
         print(f'{self.begin_datetime - datetime.now()} 后开始预订')
         sleep((self.begin_datetime - datetime.now()).seconds - 120)
         print('检查登录状态')
@@ -254,7 +253,7 @@ class Badminton():
             try:
                 stock = self.selects[stock_index]
             except IndexError:
-                print('可以预定的都试过了')
+                print('可以预订的都试过了')
                 break
             param = ('{"activityPrice":0,"activityStr":null,"address":null,"dates":null,'
                      '"extend":null,"flag":"0","isbookall":"0","isfreeman":"0","istimes":"1",'
@@ -269,7 +268,7 @@ class Badminton():
             try:
                 return_data = json.loads(r.text)
             except JSONDecodeError:
-                print(f'预定失败，第 {book_times} 次重试')
+                print(f'预订失败，第 {book_times} 次重试')
                 sleep(10)
                 continue
 
@@ -281,22 +280,22 @@ class Badminton():
                                     stock["sname"], stock["s_date"], stock["time_no"]])
 
             elif return_data['message'] == 'USERNOTLOGINYET':
-                print('JSESSIONID 过期了')
+                print('JSESSIONID 过期了，重新登录')
                 self.login()
                 continue
 
-            elif '已被预定' in return_data['message']:
+            elif '已被预订' in return_data['message']:
                 stock_index += 1
-                print('座位已被预定，尝试下一个')
+                print('场次已被预订，尝试下一个')
                 continue
 
             else:
-                print(f'预定失败，第 {book_times} 次重试')
+                print(f'预订失败：{return_data["message"]}，第 {book_times} 次重试')
                 sleep(10)
                 continue
 
         if len(self.results) == 0:
-            print('预定失败，重试次数过多，退出')
+            print('预订失败，重试次数过多，退出')
             sys.exit()
         print(f'预订成功 {len(self.results)} 个场地，1 分钟后自动支付订单')
         sleep(60)
@@ -349,14 +348,14 @@ class Badminton():
 
 
 def main():
-    parser = argparse.ArgumentParser(description='预定中山大学珠海校区羽毛球场地')
+    parser = argparse.ArgumentParser(description='预订中山大学珠海校区羽毛球场地')
     parser.add_argument('config', type=str, help='配置文件路径')
     parser.add_argument('-b', '--begin', metavar='BEGIN TIME', type=str,
-                        help='预定开始时间，如 00:05，默认 00:01', default='00:01')
+                        help='预订开始时间，如 00:05，默认 00:01', default='00:01')
     parser.add_argument('-m', '--maxtimes', type=int,
                         help='最大重试次数', default=10)
     parser.add_argument('-t', '--token', type=str,
-                        help='验证码识别平台token', default='Hvfn8AbwxNTySxrnmTknA06onCdb')
+                        help='cascaptcha api token', default='j6NKyDMPRxjHNHukp7WbBLxycL')
     parser.add_argument('-v', '--version', action='version',
                         version=f'%(prog)s {__version__}')
     par = parser.parse_args()
